﻿//DESCRIPTION:Paste a URL From the clipboard, remove the prefix, and format as a hyperlink
// Paste and format URL.jsx
//
// Modified 2016-02-05
// Keith Gilbert, Gilbert Consulting
// gilbertconsulting.com

// Main();
app.doScript(Main, undefined, undefined, UndoModes.ENTIRE_SCRIPT,"Run Script");

function Main() {
	// Check to see whether any InDesign documents are open.
	// If no documents are open, display an error message.
	if (app.documents.length > 0) {
	    if (app.selection.length > 0) {
	        if (app.selection[0].constructor.name == "InsertionPoint") {
				var myDoc = app.activeDocument;
				var myIP = app.selection[0];
				var myStory = myIP.parentStory;
	        	var myStartIndex = myIP.index;
				// Create a temporary layer and text frame to retrieve the clipboard contents
				var myTempLayer = myDoc.layers.add();
				var myTempTextFrame = myDoc.textFrames.add(myTempLayer);
				myTempTextFrame.insertionPoints[-1].select();
				app.paste();
				var myOriginalString = myTempTextFrame.parentStory.contents;
				myTempTextFrame.remove();
				myTempLayer.remove();
				// Remove the prefix
				myString = myOriginalString.slice(myOriginalString.indexOf("//")+2);
				// Insert the URL in the text
	        	myIP.contents = myString;
	        	// Create the hyperlink
	        	var myEndIndex = myStartIndex+myString.length;
	        	var myText = myStory.characters.itemByRange(myStartIndex,myEndIndex-1);
				var mySource = myDoc.hyperlinkTextSources.add(myText);
				var myDestination = myDoc.hyperlinkURLDestinations.add(myOriginalString, {hidden:true});
	        	var myHyperLink = myDoc.hyperlinks.add(mySource,myDestination);
	        	try {
		        	myHyperLink.name = myOriginalString;
	        	}
	        	catch (myError) {
		        	var n=1;
		        	while (myHyperLink.name == "Hyperlink") {
		        		try {
			        		myHyperLink.name = myOriginalString+" "+String(n);
		        		}
		        		catch (myError2) {
			        		n++;	
		        		}
					}
	        	}
	        	// Check to see if the Hyperlink character style exists
				var myCharacterStyleID = locateCharacterStyle("Hyperlink");
				if (myCharacterStyleID == "not found") {
					// Create a swatch named "Hyperlink" if it doesn't already exist
					try {
						var mySwatch = myDoc.swatches.item("Hyperlink").name; // if the swatch doesn't exist, trying to get its name throws an error
					}
					catch (myError) {
						var mySwatch = myDoc.colors.add({name:"Hyperlink"});
						if (mySwatch.space == ColorSpace.CMYK) {
							mySwatch.colorValue = [86,57,0,16];
						}
						else {
							mySwatch.colorValue = [79,92,214];
						}
					}
					// Create a Hyperlink character style
					var myCharacterStyle = myDoc.characterStyles.add({name:"Hyperlink", underline: true, fillColor: "Hyperlink"});
					mySource.appliedCharacterStyle = myCharacterStyle;
				}
				else {
	        		mySource.appliedCharacterStyle = myDoc.characterStyles.itemByID(myCharacterStyleID);
	  		    }
	        	// Position the cursor at the end and return the character style to none
	        	var myLastIP = myStory.insertionPoints[myEndIndex];
	        	myLastIP.appliedCharacterStyle = myDoc.characterStyles[0];
	        	app.select(myLastIP);
	        }
	        else {
	            // Something other than an insertion point is selected
	            alert("Please choose an insertion point with the Type tool and try again.");
	        }
	    }
	    else {
	        // Nothing is selected
	        alert("Please choose an insertion point with the Type tool and try again.");
	    }
	}
	else {
		// No documents are open, so display an error message.
		alert("No InDesign documents are open. Please open a document and try again.")
	}
	// Function to find character styles that are in style groups. Returns the id number of the character style
	function locateCharacterStyle(styleToLocate) {
		for (m=0; m<myDoc.characterStyles.count(); m++) { // iterate through the styles that aren't in style groups
			var currentStyle = myDoc.characterStyles[m].name;
			if (currentStyle == styleToLocate) {
				return myDoc.characterStyles[m].id;
			}
		}
		for (m=0; m<myDoc.characterStyleGroups.count(); m++) { // iterate through each character style group in the document...
			for (n=0; n<myDoc.characterStyleGroups[m].characterStyles.count(); n++) {
				var currentStyle = myDoc.characterStyleGroups[m].characterStyles[n].name;
				if (currentStyle == styleToLocate) {
					return myDoc.characterStyleGroups[m].characterStyles[n].id;
				}
			}
		}
		return "not found";
	}
}
